@@ -1,12 +1,3 @@
-test_that("hexagonal logo works", {
-  hex_logo(output = "hex_logo.png")
-  expect_true(file.exists("hex_logo.png"))
-  expect_false(dir.exists("hex_logo.png"))
-  expect_gt(file.size("hex_logo.png"), 0)
-  file.remove("hex_logo.png")
-  expect_false(file.exists("hex_logo.png"))
-})
-
 test_that("parallel benchmark works", {
   # Define toy function that sleeps for (60/cpus) seconds
   a <- function(cpus) {Sys.sleep(2/cpus)}
